// $Id: StandardProperty.java,v 1.6 2005/08/10 12:11:38 steveebersole Exp $
package org.hibernate.tuple;

import org.hibernate.engine.CascadeStyle;
import org.hibernate.type.Type;

/**
 * Represents a basic property within the Hibernate runtime-metamodel.
 *
 * @author Steve Ebersole
 */
public class StandardProperty extends Property {

	private final boolean lazy;
	private final boolean insertable;
	private final boolean updateable;
	private final boolean generated;
	private final boolean nullable;
	private final boolean dirtyCheckable;
	private final boolean versionable;
	private final CascadeStyle cascadeStyle;

	/**
	 * Constructs StandardProperty instances.
	 *
	 * @param name The name by which the property can be referenced within
	 * its owner.
	 * @param node The node name to use for XML-based representation of this
	 * property.
	 * @param type The Hibernate Type of this property.
	 * @param lazy Should this property be handled lazily?
	 * @param insertable Is this property an insertable value?
	 * @param updateable Is this property an updateable value?
	 * @param generated Is this property generated by the database?
	 * @param nullable Is this property a nullable value?
	 * @param checkable Is this property a checkable value?
	 * @param versionable Is this property a versionable value?
	 * @param cascadeStyle The cascade style for this property's value.
	 */
	public StandardProperty(
	        String name,
	        String node,
	        Type type,
	        boolean lazy,
	        boolean insertable,
	        boolean updateable,
	        boolean generated,
	        boolean nullable,
	        boolean checkable,
	        boolean versionable,
	        CascadeStyle cascadeStyle) {
		super(name, node, type);
		this.lazy = lazy;
		this.insertable = insertable;
		this.updateable = updateable;
		this.generated = generated;
		this.nullable = nullable;
		this.dirtyCheckable = checkable;
		this.versionable = versionable;
		this.cascadeStyle = cascadeStyle;
	}

	public boolean isLazy() {
		return lazy;
	}

	public boolean isInsertable() {
		return insertable;
	}

	public boolean isUpdateable() {
		return updateable;
	}

	public boolean isGenerated() {
		return generated;
	}

	public boolean isNullable() {
		return nullable;
	}

	public boolean isDirtyCheckable(boolean hasUninitializedProperties) {
		return isDirtyCheckable() && ( !hasUninitializedProperties || !isLazy() );
	}

	public boolean isDirtyCheckable() {
		return dirtyCheckable;
	}

	public boolean isVersionable() {
		return versionable;
	}

	public CascadeStyle getCascadeStyle() {
		return cascadeStyle;
	}
}
